@@ -18,4 +18,5 @@ if(getRversion() >= "2.15.1")
                            "statistic", ".", "parameter", "p.value",
                            "xmin", "xmax", "density", "denom",
                            "diff_prop", "group_num", "n1", "n2",
-                           "num_suc", "p_hat", "total_suc", "explan", "probs"))
+                           "num_suc", "p_hat", "total_suc", "explan", "probs",
+                           "conf.low", "conf.high"))
