@@ -30,8 +30,8 @@ specify <- function(x, formula, response = NULL,
     mutate_if(is.character, as.factor) %>%
     mutate_if(is.logical, as.factor)
 
-  if (!methods::hasArg(formula) && !methods::hasArg(response)) {
-    stop("Please specify the `response`` variable.")
+  if ((!methods::hasArg(formula) && !methods::hasArg(response))){
+    stop("Please give the `response` variable.")
   }
   if (methods::hasArg(formula)) {
     if (!rlang::is_formula(formula)) {
@@ -46,28 +46,27 @@ specify <- function(x, formula, response = NULL,
     attr(x, "response")    <- f_lhs(formula)
     attr(x, "explanatory") <- f_rhs(formula)
   }
-
-  response_col <- rlang::eval_tidy(attr(x, "response"), x)
-
-  if (!as.character(attr(x, "response")) %in% names(x)) {
+  
+  if (!(as.character(attr(x, "response")) %in% names(x))) {
     stop(paste0("The response variable `", attr(x, "response"),
                 "` cannot be found in this dataframe."))
   }
 
-  # if there's an explanatory var
+  response_col <- rlang::eval_tidy(attr(x, "response"), x)
 
-  if (!(is.null(attr(x, "explanatory")))) {
-    if (!as.character(attr(x, "explanatory")) %in% names(x)) {
+  # if there's an explanatory var
+  if(has_explanatory(x)) {
+    if(!as.character(attr(x, "explanatory")) %in% names(x)) {
       stop(paste0("The explanatory variable `", attr(x, "explanatory"),
                   "` cannot be found in this dataframe."))
     }
-    if (identical(as.character(attr(x, "response")),
+    if(identical(as.character(attr(x, "response")),
                   as.character(attr(x, "explanatory")))) {
       stop(paste("The response and explanatory variables must be different",
                  "from one another."))
     }
     explanatory_col <- rlang::eval_tidy(attr(x, "explanatory"), x)
-    if (is.character(explanatory_col)) {
+    if(is.character(explanatory_col)) {
       explanatory_col <- as.factor(explanatory_col)
     }
   }
@@ -105,22 +104,20 @@ specify <- function(x, formula, response = NULL,
                    " rows containing missing values."), call. = FALSE)
   }
 
+  
   # To help determine theoretical distribution to plot
-  if(is.null(attr(x, "response")))
-    attr(x, "response_type") <- NULL
-  else
-    attr(x, "response_type") <- class(x[[as.character(attr(x, "response"))]])
-
+  attr(x, "response_type") <- class(response_variable(x))
+  
   if(is.null(attr(x, "explanatory")))
     attr(x, "explanatory_type") <- NULL
   else
-    attr(x, "explanatory_type") <- class(
-        x[[as.character(attr(x, "explanatory"))]]
-      )
-
-  if(attr(x, "response_type") == "factor" & is.null(success) &
-     length(levels(x[[as.character(attr(x, "response"))]])) == 2)
- #    sum(table(response_col) > 0) == 2)
+    attr(x, "explanatory_type") <- class(explanatory_variable(x))
+  
+  if(attr(x, "response_type") == "factor" && is.null(success) &&
+     length(levels(response_variable(x))) == 2 &&
+     (is.null(attr(x, "explanatory_type")) ||
+     (!is.null(attr(x, "explanatory_type")) &&
+     length(levels(explanatory_variable(x))) == 2)) )
     stop(paste0("A level of the response variable `",
                 attr(x, "response"),
                 "` needs to be specified for the `success` argument ",
