@@ -7,15 +7,26 @@
 #' with "both" corresponding to "simulation" and "theoretical"
 #' @param dens_color a character or hex string specifying the color of the
 #'  theoretical density curve
-#' @param obs_stat a numeric value corresponding to what the observed 
-#' statistic is
+#' @param obs_stat a numeric value or 1x1 data frame corresponding to what
+#'  the observed statistic is
 #' @param obs_stat_color a character or hex string specifying the color of
-#'  the observed statistic
-#' @param shade_color a character or hex string specifying the color to shade
+#'  the observed statistic as a vertical line on the plot
+#' @param pvalue_fill a character or hex string specifying the color to shade
+#'  the pvalue. In previous versions of the package this was the \code{shade_color} 
+#'  argument
 #' @param direction a string specifying in which direction the shading 
-#' should occur. Options are "less", "greater", or "two_sided".
-#' Can also specify "left", "right", or "both".
-#' @param ... currently ignored
+#' should occur. Options are "less", "greater", or "two_sided" for p-value.
+#' Can also give "left", "right", or "both" for p-value. For confidence 
+#' intervals, use "between".
+#' and give the endpoint values in \code{endpoints}
+#' @param endpoints a 2 element vector or a 1 x 2 data frame containing the
+#'  lower and upper values to be plotted. Most useful for visualizing
+#'  conference intervals.
+#' @param endpoints_color a character or hex string specifying the color of
+#'  the observed statistic as a vertical line on the plot 
+#' @param ci_fill a character or hex string specifying the color to shade
+#'  the confidence interval
+#' @param ... other arguments passed along to ggplot2
 #' @importFrom ggplot2 ggplot geom_histogram aes stat_function ggtitle  
 #' @importFrom ggplot2 xlab ylab geom_vline geom_rect geom_bar
 #' @importFrom stats dt qt df qf dnorm qnorm dchisq qchisq
@@ -57,41 +68,65 @@
 visualize <- function(data, bins = 15, method = "simulation", 
                       dens_color = "black",
                       obs_stat = NULL, 
-                      obs_stat_color = "#e51010",#"#00BFC4",
-                      shade_color = "#efb8b8",
-                      direction = NULL, ...) {
+                      obs_stat_color = "red2",
+                      pvalue_fill = "pink",
+                      direction = NULL, 
+                      endpoints = NULL, 
+                      endpoints_color = "mediumaquamarine",
+                      ci_fill = "turquoise", ...) {
   
   assertive::assert_is_data.frame(data)
   assertive::assert_is_numeric(bins)
   assertive::assert_is_character(method)
-  if(!is.null(obs_stat))
-    assertive::assert_is_numeric(obs_stat)
   assertive::assert_is_character(dens_color)
   assertive::assert_is_character(obs_stat_color)
-  assertive::assert_is_character(shade_color)
+  assertive::assert_is_character(pvalue_fill)
   if(!is.null(direction))
     assertive::assert_is_character(direction)
-  
-  
-  if(!is.null(direction) && is.null(obs_stat))
-    stop("Shading requires observed statistic `obs_stat` value to be given.")
-  
+  if(is.data.frame(endpoints) && 
+     ( (nrow(endpoints) != 1) || (ncol(endpoints) != 2) ) ){
+    stop(paste("Expecting `endpoints` to be a 1 x 2 data frame or 2",
+                  "element vector."))
+  }
+  if(is.vector(endpoints) && ( length(endpoints) != 2) ) {
+    warning(paste("Expecting `endpoints` to be a 1 x 2 data frame or 2", 
+                  "element vector.",
+                  "Using the first two entries as", 
+                  "the `endpoints`."))
+    endpoints <- endpoints[1:2]
+  }
+  if(is.data.frame(endpoints))
+    endpoints <- unlist(endpoints)
+  obs_stat <- check_obs_stat(obs_stat)
+  if(!is.null(direction) && 
+     (is.null(obs_stat) + is.null(endpoints)) != 1)
+    stop(paste("Shading requires either `endpoints` values for a", 
+               "confidence interval or the observed statistic", 
+               "`obs_stat` to be provided."))
+
   if(method == "simulation"){
     
     infer_plot <- visualize_simulation(data = data, bins = bins, 
-                                          dens_color = dens_color,
-                                          obs_stat = obs_stat, 
-                                          obs_stat_color = obs_stat_color,
-                                          direction = direction, 
-                                          shade_color = shade_color, ...)
+                                       dens_color = dens_color,
+                                       obs_stat = obs_stat, 
+                                       obs_stat_color = obs_stat_color,
+                                       direction = direction, 
+                                       pvalue_fill = pvalue_fill,
+                                       endpoints = endpoints, 
+                                       ci_fill = ci_fill,
+                                       ...)
     
   } else if(method == "theoretical"){
+    
     infer_plot <- visualize_theoretical(data = data,
                                         dens_color = dens_color,
                                         obs_stat = obs_stat, 
                                         obs_stat_color = obs_stat_color,
                                         direction = direction, 
-                                        shade_color = shade_color, ...)
+                                        pvalue_fill = pvalue_fill,
+                                        endpoints = endpoints, 
+                                        ci_fill = ci_fill,
+                                        ...)
     
     
   } else if(method == "both"){
@@ -100,7 +135,8 @@ visualize <- function(data, bins = 15, method = "simulation",
       stop(paste0('`generate()` and `calculate()` are both required ', 
                   'to be done prior to `visualize(method = "both")`'))
     
-    if(length(unique(data$replicate)) < 100)
+    if(("replicate" %in% names(data)) &&
+         length(unique(data$replicate)) < 100)
       warning(paste("With only", length(unique(data$stat)),
                     "replicates, it may be difficult to see the",
                     "relationship between simulation and theory."))
@@ -110,17 +146,30 @@ visualize <- function(data, bins = 15, method = "simulation",
                                  obs_stat = obs_stat, 
                                  obs_stat_color = obs_stat_color,
                                  direction = direction,
-                                 shade_color = shade_color, ...)
+                                 pvalue_fill = pvalue_fill,
+                                 endpoints = endpoints, 
+                                 ci_fill = ci_fill,
+                                 ...)
   } else {
     stop(paste("Provide `method` with one of three options:",
-               "`theoretical`, `both`, or `simulation`",
-               "`simulation` is the default.")
+               '`"theoretical"`, `"both"`, or `"simulation"`',
+               '`"simulation"` is the default.')
     )
   }
   
-  if(!is.null(obs_stat) && !is.null(direction)){
+  if(!is.null(obs_stat)){#&& !is.null(direction)
     infer_plot <- infer_plot +
-      geom_vline(xintercept = obs_stat, size = 2, color = obs_stat_color)
+      geom_vline(xintercept = obs_stat, size = 2, color = obs_stat_color, ...)
+  }
+  
+  if(!is.null(endpoints)){
+    if(!is.null(obs_stat))
+      warning(paste("Values for both `endpoints` and `obs_stat` were given",
+                  "when only one should be set. Ignoring `obs_stat` values."))
+    infer_plot <- infer_plot +
+      geom_vline(xintercept = endpoints, size = 2, 
+                 color = endpoints_color, 
+                 ...)
   }
   
   infer_plot
@@ -128,7 +177,7 @@ visualize <- function(data, bins = 15, method = "simulation",
 
 
 theory_t_plot <- function(deg_freedom, statistic_text = "t", 
-                          dens_color = "black", ...){
+                          dens_color = dens_color, ...){
   ggplot(data.frame(x = c(qt(0.001, deg_freedom), 
                           qt(0.999, deg_freedom)))) + 
     stat_function(mapping = aes(x), fun = dt, args = list(df = deg_freedom), 
@@ -140,14 +189,21 @@ theory_t_plot <- function(deg_freedom, statistic_text = "t",
 }
 
 both_t_plot <- function(data = data, deg_freedom, statistic_text = "t",
-                        dens_color = "black",
-                        obs_stat = NULL,
-                        direction = NULL, bins = 15,...){
+                        dens_color,
+                        obs_stat,
+                        direction, 
+                        bins,
+                        pvalue_fill, 
+                        endpoints, 
+                        ci_fill, ...){
   
   infer_t_plot <- shade_density_check(data = data,
                                       obs_stat = obs_stat,
                                       direction = direction,
-                                      bins = bins)
+                                      bins = bins,
+                                      endpoints = endpoints,
+                                      pvalue_fill = pvalue_fill,
+                                      ci_fill = ci_fill)
 
   infer_t_plot +
     stat_function(fun = dt, args = list(df = deg_freedom), 
@@ -159,7 +215,8 @@ both_t_plot <- function(data = data, deg_freedom, statistic_text = "t",
 }
 
 theory_anova_plot <- function(deg_freedom_top, deg_freedom_bottom, 
-                              statistic_text = "F", dens_color = "black", ...){
+                              statistic_text = "F", 
+                              dens_color = dens_color, ...){
   ggplot(data.frame(x = c(qf(0.001, deg_freedom_top, deg_freedom_bottom), 
                           qf(0.999, deg_freedom_top, deg_freedom_bottom)))) + 
     stat_function(mapping = aes(x), fun = df, 
@@ -172,18 +229,26 @@ theory_anova_plot <- function(deg_freedom_top, deg_freedom_bottom,
 
 both_anova_plot <- function(data, deg_freedom_top, 
                             deg_freedom_bottom, statistic_text = "F",
-                            dens_color = "black",
-                            obs_stat = NULL,
-                            direction = NULL, bins = 15,....){
+                            dens_color,
+                            obs_stat,
+                            direction, 
+                            bins,
+                            endpoints,
+                            pvalue_fill,
+                            ci_fill,
+                            ....){
   
   if(!is.null(direction) && !(direction %in% c("greater", "right")))
     warning(paste("F usually corresponds to right-tailed tests. Proceed",
-                  "with caution."))
+                  "with caution."), call. = FALSE)
   
   infer_anova_plot <- shade_density_check(data = data, 
                                           obs_stat = obs_stat,
                                           direction = direction,
-                                          bins = bins)
+                                          bins = bins,
+                                          endpoints = endpoints,
+                                          pvalue_fill = pvalue_fill,
+                                          ci_fill = ci_fill)
   
   infer_anova_plot <- infer_anova_plot +
     stat_function(fun = df, 
@@ -195,7 +260,8 @@ both_anova_plot <- function(data, deg_freedom_top,
     ylab("")  
 }
 
-theory_z_plot <- function(statistic_text = "z", dens_color = "black",  ...){
+theory_z_plot <- function(statistic_text = "z", dens_color = dens_color,  ...){
+  
   ggplot(data.frame(x = c(qnorm(0.001), qnorm(0.999)))) + 
     stat_function(mapping = aes(x), fun = dnorm, color = dens_color) +
     ggtitle(paste("Theoretical", statistic_text, "Null Distribution")) +
@@ -204,13 +270,22 @@ theory_z_plot <- function(statistic_text = "z", dens_color = "black",  ...){
 }
 
 both_z_plot <- function(data, statistic_text = "z",
-                        dens_color = "black",
-                        obs_stat = NULL,
-                        direction = NULL, bins = 15,...){
+                        dens_color,
+                        obs_stat,
+                        direction,
+                        pvalue_fill,
+                        bins,
+                        endpoints,
+                        ci_fill,
+                        ...){
+  
   infer_z_plot <- shade_density_check(data = data, 
                                       obs_stat = obs_stat,
                                       direction = direction,
-                                      bins = bins)
+                                      bins = bins,
+                                      endpoints = endpoints,
+                                      pvalue_fill = pvalue_fill,
+                                      ci_fill = ci_fill)
   
   infer_z_plot +
     stat_function(fun = dnorm, color = dens_color) +
@@ -222,7 +297,7 @@ both_z_plot <- function(data, statistic_text = "z",
 
 theory_chisq_plot <- function(deg_freedom, 
                               statistic_text = "Chi-Square", 
-                              dens_color = "black", ...){
+                              dens_color = dens_color, ...){
   ggplot(data.frame(x = c(qchisq(0.001, deg_freedom), 
                           qchisq(0.999, deg_freedom)))) + 
     stat_function(mapping = aes(x), fun = dchisq, 
@@ -234,18 +309,26 @@ theory_chisq_plot <- function(deg_freedom,
 }
 
 both_chisq_plot <- function(data, deg_freedom, statistic_text = "Chi-Square",
-                            dens_color = "black",
-                            obs_stat = NULL,
-                            direction = "greater", bins = 15,...){
+                            dens_color,
+                            obs_stat,
+                            direction, 
+                            bins, 
+                            endpoints, 
+                            pvalue_fill = pvalue_fill,
+                            ci_fill = ci_fill,
+                            ...){
   
   if(!is.null(direction) && !(direction %in% c("greater", "right")))
      warning(paste("Chi-square usually corresponds to right-tailed tests.",
-                   "Proceed with caution."))
+                   "Proceed with caution."), call. = FALSE)
   
   infer_chisq_plot <- shade_density_check(data = data,
                                           obs_stat = obs_stat,
                                           direction = direction,
-                                          bins = bins)
+                                          bins = bins,
+                                          endpoints = endpoints,
+                                          pvalue_fill = pvalue_fill,
+                                          ci_fill = ci_fill)
   
   infer_chisq_plot +
     stat_function(fun = dchisq, args = list(df = deg_freedom), 
@@ -257,114 +340,137 @@ both_chisq_plot <- function(data, deg_freedom, statistic_text = "Chi-Square",
 }
 
 
-shade_density_check <- function(data = data,
+shade_density_check <- function(data,
                                 obs_stat, 
                                 direction, 
                                 bins, 
                                 density = TRUE, 
-                                shade_color = "#efb8b8", ...) {
+                                pvalue_fill,
+                                endpoints,
+                                ci_fill, ...) {
   
   if(is.null(direction) || is.null(obs_stat)){
     if(density){
       gg_plot <- ggplot(data = data, mapping = aes(x = stat)) +
         geom_histogram(bins = bins, color = "white",
-                       mapping = aes(y = ..density..))
-    } else {
+                       mapping = aes(y = ..density..), ...)
+    } #else {
       # Not sure if needed? Can't get tests to find it
       #gg_plot <- ggplot(data = data, mapping = aes(x = stat)) +
-      #  geom_histogram(bins = bins, color = "white")
-    }
+      #  geom_histogram(bins = bins, color = "white", ...)
+    #}
   }
   
-  if(!is.null(obs_stat)){
+  if(xor(!is.null(obs_stat), !is.null(endpoints))){
     if(!is.null(direction)){
       if(density){
         gg_plot <- ggplot(data = data, mapping = aes(x = stat)) +
           geom_histogram(bins = bins, color = "white",
-                         mapping = aes(y = ..density..))
+                         mapping = aes(y = ..density..), ...)
       } else {
         gg_plot <- ggplot(data = data, mapping = aes(x = stat)) +
-          geom_histogram(bins = bins, color = "white")
+          geom_histogram(bins = bins, color = "white", ...)
       }
       
       if(direction %in% c("less", "left")){
         gg_plot <- gg_plot +
-          geom_rect(fill = shade_color, alpha = 0.01, 
-                    aes(xmin = -Inf, xmax = obs_stat, ymin = 0, ymax = Inf))
+          geom_rect(fill = pvalue_fill, alpha = 0.01, 
+                    aes(xmin = -Inf, xmax = obs_stat, ymin = 0, ymax = Inf), 
+                    ...)
       }
       if(direction %in% c("greater", "right")){
         gg_plot <- gg_plot +
-          geom_rect(fill = shade_color, alpha = 0.01, 
-                    aes(xmin = obs_stat, xmax = Inf, ymin = 0, ymax = Inf))
+          geom_rect(fill = pvalue_fill, alpha = 0.01, 
+                    aes(xmin = obs_stat, xmax = Inf, ymin = 0, ymax = Inf), 
+                    ...)
       }
       
       if(direction %in% c("two_sided", "both") && 
          obs_stat >= stats::median(data$stat)){
         gg_plot <- gg_plot +
-          geom_rect(fill = shade_color, alpha = 0.01,
+          geom_rect(fill = pvalue_fill, alpha = 0.01,
                     mapping = aes(xmin = obs_stat, xmax = Inf, ymin = 0, 
-                                  ymax = Inf)) +
-          geom_rect(fill = shade_color, alpha = 0.01,
+                                  ymax = Inf), ...) +
+          geom_rect(fill = pvalue_fill, alpha = 0.01,
                     mapping = aes(
                       xmin = -Inf, 
                       xmax = stats::quantile(
                         data$stat, 
                         probs = 1 - get_percentile(data$stat, obs_stat)
                       ),
-                      ymin = 0, ymax = Inf)
+                      ymin = 0, ymax = Inf, ...)
           ) 
       }
       
       if(direction %in% c("two_sided", "both") && 
          obs_stat < stats::median(data$stat)){
         gg_plot <- gg_plot +
-          geom_rect(fill = shade_color, alpha = 0.01,
+          geom_rect(fill = pvalue_fill, alpha = 0.01,
                     mapping = aes(xmin = -Inf, xmax = obs_stat, ymin = 0, 
-                                  ymax = Inf)) +
-          geom_rect(fill = shade_color, alpha = 0.01,
+                                  ymax = Inf), ...) +
+          geom_rect(fill = pvalue_fill, alpha = 0.01,
                     mapping = aes( 
                       xmin = stats::quantile(
                         data$stat, 
                         probs = 1 - get_percentile(data$stat, obs_stat)
-                      ), xmax = Inf, ymin = 0, ymax = Inf)
+                      ), xmax = Inf, ymin = 0, ymax = Inf, ...)
           ) 
       }
     }
+
+  
+    if(direction == "between"){
+      gg_plot <- gg_plot +
+        geom_rect(fill = ci_fill, alpha = 0.01, 
+                  aes(xmin = endpoints[1], 
+                      xmax = endpoints[2], ymin = 0, ymax = Inf), 
+                  ...)
+    }
+  
   }
     gg_plot
 }
 
-visualize_simulation <- function(data, bins = 15, method = "simulation", 
-                                    dens_color = "black",
-                                    obs_stat = NULL, 
-                                    obs_stat_color = "#e51010",
-                                    direction = NULL, 
-                                    shade_color = "#efb8b8", ...) {
+visualize_simulation <- function(data, bins, 
+                                 method = "simulation", 
+                                 dens_color,
+                                 obs_stat, 
+                                 obs_stat_color,
+                                 direction, 
+                                 pvalue_fill,
+                                 endpoints,
+                                 ci_fill, ...) {
   if(is.null(direction)){
     if(length(unique(data$stat)) >= 10)
       infer_plot <- ggplot(data = data, mapping = aes(x = stat)) +
-        geom_histogram(bins = bins, color = "white")
+        geom_histogram(bins = bins, color = "white", ...)
     else
-      infer_plot <- ggplot(data = data, mapping = aes(x = factor(stat))) +
-        geom_bar() +
+      infer_plot <- ggplot(data = data, mapping = aes(x = stat)) +
+        geom_bar(...) +
         xlab("stat")
   } else {
     infer_plot <- shade_density_check(data = data,
-                                        obs_stat = obs_stat,
-                                        direction = direction,
-                                        bins = bins,
-                                        density = FALSE,
-                                        shade_color = shade_color)
+                                      obs_stat = obs_stat,
+                                      direction = direction,
+                                      bins = bins,
+                                      density = FALSE,
+                                      pvalue_fill = pvalue_fill,
+                                      endpoints = endpoints, 
+                                      ci_fill = ci_fill
+    )
   }
   infer_plot
 }
 
 visualize_theoretical <- function(data,
-                                  dens_color = "black",
-                                  obs_stat = NULL, 
-                                  obs_stat_color = "#e51010",#"#00BFC4",
-                                  direction = NULL, 
-                                  shade_color = "#efb8b8", ...) {
+                                  dens_color,
+                                  obs_stat, 
+                                  obs_stat_color,
+                                  direction, 
+                                  pvalue_fill, 
+                                  endpoints,
+                                  ci_fill, 
+                                  ...) {
   
   warning(paste("Check to make sure the conditions", 
                 "have been met for",
@@ -399,7 +505,8 @@ visualize_theoretical <- function(data,
   
   else if(attr(data, "theory_type") %in% 
           c("One sample prop z", "Two sample props z")){
-    infer_plot <- theory_z_plot(statistic_text = "z")
+    infer_plot <- theory_z_plot(statistic_text = "z", 
+                                dens_color = dens_color)
   }
   
   else if(attr(data, "theory_type") %in% 
@@ -414,9 +521,9 @@ visualize_theoretical <- function(data,
                                     dens_color = dens_color)
   }
   
-  else
-    stop(paste0("'", attr(data, "theory_type"), "' is not implemented",
-                "(possibly yet)."))
+#  else
+#    stop(paste0("'", attr(data, "theory_type"), "' is not implemented",
+#                "(possibly yet)."))
   
   # Move into its own function
   
@@ -424,51 +531,61 @@ visualize_theoretical <- function(data,
     if(!is.null(direction)){
       if(direction %in% c("less", "left")){
         infer_plot <- infer_plot +
-          geom_rect(data = data.frame(obs_stat), fill = shade_color, 
+          geom_rect(data = data.frame(obs_stat), fill = pvalue_fill, 
                     alpha = 0.6,
-                    aes(xmin = -Inf, xmax = obs_stat, ymin = 0, ymax = Inf))
+                    aes(xmin = -Inf, xmax = obs_stat, ymin = 0, ymax = Inf),
+                    ...)
       }
       if(direction %in% c("greater", "right")){
         infer_plot <- infer_plot +
-          geom_rect(data = data.frame(obs_stat), fill = shade_color, 
+          geom_rect(data = data.frame(obs_stat), fill = pvalue_fill, 
                     alpha = 0.6,
                     aes(xmin = obs_stat,
-                        xmax = Inf, ymin = 0, ymax = Inf))
+                        xmax = Inf, ymin = 0, ymax = Inf),
+                    ...)
       }
       
       # Assuming two-tailed shading will only happen with theoretical 
       # distributions centered at 0
       if(direction %in% c("two_sided", "both") && obs_stat >= 0){
         infer_plot <- infer_plot +
-          geom_rect(data = data.frame(obs_stat), fill = shade_color, 
+          geom_rect(data = data.frame(obs_stat), fill = pvalue_fill, 
                     alpha = 0.6,
-                    aes(xmin = obs_stat, xmax = Inf, ymin = 0, ymax = Inf)) +
-          geom_rect(data = data.frame(obs_stat), fill = shade_color, 
+                    aes(xmin = obs_stat, xmax = Inf, ymin = 0, ymax = Inf),
+                    ...) +
+          geom_rect(data = data.frame(obs_stat), fill = pvalue_fill, 
                     alpha = 0.6,
-                    aes(xmin = -Inf, xmax = -obs_stat, ymin = 0, ymax = Inf))
+                    aes(xmin = -Inf, xmax = -obs_stat, ymin = 0, ymax = Inf),
+                    ...)
       }
 
       if(direction %in% c("two_sided", "both") && obs_stat < 0){
         infer_plot <- infer_plot +
-          geom_rect(data = data.frame(obs_stat), fill = shade_color, 
+          geom_rect(data = data.frame(obs_stat), fill = pvalue_fill, 
                     alpha = 0.6,
-                    aes(xmin = -Inf, xmax = obs_stat, ymin = 0, ymax = Inf)) +
-          geom_rect(data = data.frame(obs_stat), fill = shade_color, 
+                    aes(xmin = -Inf, xmax = obs_stat, ymin = 0, ymax = Inf),
+                    ...) +
+          geom_rect(data = data.frame(obs_stat), fill = pvalue_fill, 
                     alpha = 0.6,
-                    aes(xmin = -obs_stat, xmax = Inf, ymin = 0, ymax = Inf))
+                    aes(xmin = -obs_stat, xmax = Inf, ymin = 0, ymax = Inf),
+                    ...)
       }
     }
   }
   
+  # To implement: plotting of theoretical confidence interval values
+  
   infer_plot
 }
 
-visualize_both <- function(data = data, bins = bins, 
-                           dens_color = dens_color,
-                           obs_stat = obs_stat, 
-                           obs_stat_color = "#e51010",#"#00BFC4",
-                           direction = direction, 
-                           shade_color = "#efb8b8", ...) {
+visualize_both <- function(data, bins, 
+                           dens_color,
+                           obs_stat, 
+                           obs_stat_color,
+                           direction, 
+                           pvalue_fill, 
+                           endpoints, 
+                           ci_fill, ...) {
   
   warning(paste("Check to make sure the conditions", 
                 "have been met for",
@@ -487,7 +604,10 @@ visualize_both <- function(data = data, bins = bins,
                               dens_color = dens_color,
                               bins = bins,
                               direction = direction,
-                              obs_stat = obs_stat)
+                              obs_stat = obs_stat,
+                              pvalue_fill = pvalue_fill,
+                              endpoints = endpoints,
+                              ci_fill = ci_fill)
   }
   
   else if(attr(data, "theory_type") == "ANOVA"){
@@ -499,7 +619,10 @@ visualize_both <- function(data = data, bins = bins,
       dens_color = dens_color,
       bins = bins,
       direction = direction,
-      obs_stat = obs_stat) 
+      obs_stat = obs_stat,
+      pvalue_fill = pvalue_fill,
+      endpoints = endpoints,
+      ci_fill = ci_fill)
   }
   
   else if(attr(data, "theory_type") %in% 
@@ -509,7 +632,10 @@ visualize_both <- function(data = data, bins = bins,
                               dens_color = dens_color,
                               bins = bins,
                               direction = direction,
-                              obs_stat = obs_stat) 
+                              obs_stat = obs_stat,
+                              pvalue_fill = pvalue_fill,
+                              endpoints = endpoints,
+                              ci_fill = ci_fill)
   }
   
   else if(
@@ -520,12 +646,15 @@ visualize_both <- function(data = data, bins = bins,
                                   statistic_text = "Chi-Square", 
                                   dens_color = dens_color,
                                   bins = bins,
-                                  direction = "right",
-                                  obs_stat = obs_stat) 
+                                  direction = direction,
+                                  obs_stat = obs_stat,
+                                  pvalue_fill = pvalue_fill,
+                                  endpoints = endpoints,
+                                  ci_fill = ci_fill)
   }
   
-  else
-    stop(paste0("'", attr(data, "theory_type"), "' is not implemented yet."))
+#  else
+#    stop(paste0("'", attr(data, "theory_type"), "' is not implemented yet."))
   
   infer_plot
 }
